from setuptools import setup

name = 'memrise'
version = '1.1.0'
install_requires = ['requests','bs4','mateco','googletrans==4.0.0rc1']
description = 'Scaping MEM course infomation'
author='Joseph Quang'
author_email='tquang.sdh20@hcmut.edu.vn'
url= 'https://github.com/tquangsdh20/memrise'

with open("README.md",'r',encoding='utf-8') as fh:
    long_description = fh.read()

keywords = list(name)

classifiers = [
    'Intended Audience :: Education',
    'Intended Audience :: Information Technology',
    'Intended Audience :: Developers',
    'Intended Audience :: End Users/Desktop',
    'Natural Language :: French',
    'Development Status :: 1 - Planning',
    'Operating System :: OS Independent',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
]
###################################################
setup(
    name=name,
    version = version,

    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
	author=author,
	author_email=author_email,
	url=url,
    classifiers = classifiers,
    packages=[name],
    package_dir = {'':'src'},
    install_requires = install_requires,
    include_package_data=True,
    license='MIT',
	keywords=keywords,
)


#_*utf-8*_
#__init__.py
"""Library Memrise Scraping"""
from .memrise import _Course_,_Level_
from .memdb import _Data_
from .constant import _LANGUAGE_INFO_

class Level(_Level_):
    '''Level of the Memrise course infomation'''
    def get_record(self)->tuple:
        '''Return the record of level'''
        return self._get_record()
    def get_words(self)->list:
        '''Return the words in level'''
        return self._get_words()
    def update(self,db):
        '''Load data into database'''
        self._update(db)

class Course(_Course_):
    '''Course of Memrise information'''
    def get_record(self) -> tuple:
        '''Return the record of course'''
        return self._get_record()
    def get_levels(self) -> list[Level]:
        '''Return the list of levels in course'''
        return self._get_levels(Level)

    def update(self,db):
        '''Load data into database'''
        self._update(db)
    # def get_words(self) -> list:
    #     '''Return the list of words in course'''
    #     return self._get_words()

class Database(_Data_):
    '''Database for store data'''
    def connect(self):
        self.conn,self.cur = self._get_connection()
    
    def init(self)->None:
        self._init_database()
        print(_LANGUAGE_INFO_)

    def execute(self,cmd,records):
        '''Update database with CMD'''
        for record in records:
            try:
                self.cur.execute(cmd,record)
            except:
                print('RecordError:',record)
        self.conn.commit()

    def update_db_en(self,course_id,language):
        '''Update meanings and ipa of English language in database\n
        ~~~~~~~~~~~~~~~~
        Parameters:\n
        `course_id` Identify of the Memrise Course
        `language` Input your mother language (Format: 'en', 'vi', 'fr' ...)
        '''
        self._update_db_en(course_id,language)

    def update_db(self,course_id,language):
        '''Update meanings language in database\n
        ~~~~~~~~~~~~~~~~
        Parameters:\n
        `course_id` Identify of the Memrise Course
        `language` Input your mother language (Format: 'en', 'vi', 'fr' ...)
        '''
        self._update_db(course_id,language)

    def close(self):
        self.conn.commit()
        self.cur.close()


__all__ = ['Level','Course','Database']
        
